import { getFarcasterUser, getInteractions } from './farcaster-api';

export default async function handler(req, res) {
  if (req.method !== 'POST') {
    return res.status(405).json({ error: 'Method not allowed' });
  }

  try {
    const { fid, requestType } = req.body;
    
    if (!fid) {
      return res.status(400).json({ error: 'Missing FID' });
    }

    // Get user's interaction data
    const interactions = await getInteractions(fid);
    
    // Calculate most frequent interactions
    const topFriends = interactions
      .reduce((acc, interaction) => {
        acc[interaction.targetFid] = (acc[interaction.targetFid] || 0) + 1;
        return acc;
      }, {})
      .sort((a, b) => b.count - a.count)
      .slice(0, 5);

    // Get user details for top friends
    const friendDetails = await Promise.all(
      topFriends.map(friend => getFarcasterUser(friend.fid))
    );

    return res.status(200).json({
      version: 'vNext',
      image: {
        src: `https://friendstatsframehub.pro/api/generate-stats-image?fid=${fid}`,
        aspectRatio: '1.91:1'
      },
      buttons: [
        {
          label: 'SHARE RESULTS',
          action: 'post'
        }
      ]
    });
  } catch (error) {
    console.error('Frame API error:', error);
    return res.status(500).json({ error: 'Internal server error' });
  }
}
